@@ -6,11 +6,14 @@ set -e -x -u
 export CGO_ENABLED=0
 repro_flags="-ldflags=-buildid= -trimpath"
 
-go fmt ./cmd/... ./pkg/... ./test/...
 go mod vendor
 go mod tidy
+go fmt ./cmd/... ./pkg/... ./test/...
 
 go build $repro_flags -o kapp ./cmd/kapp/...
 ./kapp version
 
+# compile tests, but do not run them: https://github.com/golang/go/issues/15513#issuecomment-839126426
+go test --exec=echo ./... >/dev/null
+
 echo "Success"
